@@ -18,7 +18,6 @@ from plugwise.constants import (
     STATUS,
     SYSTEM,
     GwEntityData,
-    SmileProps,
     ThermoLoc,
 )
 from plugwise.exceptions import (
@@ -69,7 +68,6 @@ class Smile(SmileComm):
         self._opentherm_device = False
         self._schedule_old_states: dict[str, dict[str, str]] = {}
         self._smile_api: SmileAPI | SmileLegacyAPI
-        self._smile_props: SmileProps = {}
         self._stretch_v2 = False
         self._target_smile: str = NONE
         self.smile_hostname: str = NONE
@@ -86,26 +84,22 @@ class Smile(SmileComm):
     @property
     def cooling_present(self) -> bool:
         """Return the cooling capability."""
-        if "cooling_present" in self._smile_props:
-            return self._smile_props["cooling_present"]
-        return False
+        return self._smile_api.cooling_present
 
     @property
     def gateway_id(self) -> str:
         """Return the gateway-id."""
-        return self._smile_props["gateway_id"]
+        return self._smile_api.gateway_id
 
     @property
     def heater_id(self) -> str:
         """Return the heater-id."""
-        if "heater_id" in self._smile_props:
-            return self._smile_props["heater_id"]
-        return NONE
+        return self._smile_api.heater_id
 
     @property
     def item_count(self) -> int:
         """Return the item-count."""
-        return self._smile_props["item_count"]
+        return self._smile_api.item_count
 
     @property
     def reboot(self) -> bool:
@@ -162,7 +156,6 @@ class Smile(SmileComm):
                 self._opentherm_device,
                 self._request,
                 self._schedule_old_states,
-                self._smile_props,
                 self.smile_hostname,
                 self.smile_hw_version,
                 self.smile_mac_address,
@@ -179,7 +172,6 @@ class Smile(SmileComm):
                 self._on_off_device,
                 self._opentherm_device,
                 self._request,
-                self._smile_props,
                 self._stretch_v2,
                 self._target_smile,
                 self.smile_hostname,
@@ -198,7 +190,9 @@ class Smile(SmileComm):
 
         return self.smile_version
 
-    async def _smile_detect(self, result: etree, dsmrmain: etree) -> None:
+    async def _smile_detect(
+        self, result: etree.Element, dsmrmain: etree.Element
+    ) -> None:
         """Helper-function for connect().
 
         Detect which type of Plugwise Gateway is being connected.
@@ -256,10 +250,8 @@ class Smile(SmileComm):
             # For Adam, Anna, determine the system capabilities:
             # Find the connected heating/cooling device (heater_central),
             # e.g. heat-pump or gas-fired heater
-            onoff_boiler: etree = result.find("./module/protocols/onoff_boiler")
-            open_therm_boiler: etree = result.find(
-                "./module/protocols/open_therm_boiler"
-            )
+            onoff_boiler = result.find("./module/protocols/onoff_boiler")
+            open_therm_boiler = result.find("./module/protocols/open_therm_boiler")
             self._on_off_device = onoff_boiler is not None
             self._opentherm_device = open_therm_boiler is not None
 
@@ -272,7 +264,7 @@ class Smile(SmileComm):
                 self._elga = True
 
     async def _smile_detect_legacy(
-        self, result: etree, dsmrmain: etree, model: str
+        self, result: etree.Element, dsmrmain: etree.Element, model: str
     ) -> str:
         """Helper-function for _smile_detect().
 
@@ -298,11 +290,12 @@ class Smile(SmileComm):
             self.smile_version = parse(system.find("./gateway/firmware").text)
             return_model = str(system.find("./gateway/product").text)
             self.smile_hostname = system.find("./gateway/hostname").text
-            # If wlan0 contains data it's active, so eth0 should be checked last
+            # If wlan0 contains data it's active, eth0 should be checked last as is preferred
             for network in ("wlan0", "eth0"):
                 locator = f"./{network}/mac"
                 if (net_locator := system.find(locator)) is not None:
                     self.smile_mac_address = net_locator.text
+
         # P1 legacy:
         elif dsmrmain is not None:
             status = await self._request(STATUS)
