@@ -27,7 +27,9 @@ from defusedxml import ElementTree as etree
 from munch import Munch
 
 
-def get_zigbee_data(module: etree, module_data: ModuleData, legacy: bool) -> None:
+def get_zigbee_data(
+    module: etree.Element, module_data: ModuleData, legacy: bool
+) -> None:
     """Helper-function for _get_module_data()."""
     if legacy:
         # Stretches
@@ -49,13 +51,18 @@ class SmileCommon:
         """Init."""
         self._cooling_present: bool
         self._count: int
-        self._domain_objects: etree
+        self._domain_objects: etree.Element
         self._heater_id: str = NONE
         self._on_off_device: bool
         self.gw_entities: dict[str, GwEntityData] = {}
         self.smile_name: str
         self.smile_type: str
 
+    @property
+    def heater_id(self) -> str:
+        """Return the heater-id."""
+        return self._heater_id
+
     def smile(self, name: str) -> bool:
         """Helper-function checking the smile-name."""
         return self.smile_name == name
@@ -63,10 +70,10 @@ class SmileCommon:
     def _appl_heater_central_info(
         self,
         appl: Munch,
-        xml_1: etree,
+        xml_1: etree.Element,
         legacy: bool,
-        xml_2: etree = None,
-        xml_3: etree = None,
+        xml_2: etree.Element = None,
+        xml_3: etree.Element = None,
     ) -> Munch:
         """Helper-function for _appliance_info_finder()."""
         # Find the valid heater_central
@@ -74,6 +81,9 @@ class SmileCommon:
         xml_2 = return_valid(xml_2, self._domain_objects)
         self._heater_id = check_heater_central(xml_2)
 
+        if self._heater_id == NONE:
+            return Munch()  # pragma: no cover
+
         #  Info for On-Off device
         if self._on_off_device:
             appl.name = "OnOff"  # pragma: no cover
@@ -101,7 +111,7 @@ class SmileCommon:
         return appl
 
     def _appl_thermostat_info(
-        self, appl: Munch, xml_1: etree, xml_2: etree = None
+        self, appl: Munch, xml_1: etree.Element, xml_2: etree.Element = None
     ) -> Munch:
         """Helper-function for _appliance_info_finder()."""
         locator = "./logs/point_log[type='thermostat']/thermostat"
@@ -190,7 +200,7 @@ class SmileCommon:
         return switch_groups
 
     def _get_lock_state(
-        self, xml: etree, data: GwEntityData, stretch_v2: bool = False
+        self, xml: etree.Element, data: GwEntityData, stretch_v2: bool = False
     ) -> None:
         """Helper-function for _get_measurement_data().
 
@@ -209,9 +219,9 @@ class SmileCommon:
 
     def _get_module_data(
         self,
-        xml_1: etree,
+        xml_1: etree.Element,
         locator: str,
-        xml_2: etree = None,
+        xml_2: etree.Element = None,
         legacy: bool = False,
     ) -> ModuleData:
         """Helper-function for _energy_device_info_finder() and _appliance_info_finder().
