@@ -16,7 +16,6 @@ from plugwise.constants import (
     OFF,
     ActuatorData,
     GwEntityData,
-    SmileProps,
 )
 from plugwise.helper import SmileHelper
 from plugwise.util import remove_empty_platform_dicts
@@ -27,28 +26,19 @@ class SmileData(SmileHelper):
 
     def __init__(self) -> None:
         """Init."""
-        self._smile_props: SmileProps
+        super().__init__()
         self._zones: dict[str, GwEntityData] = {}
-        SmileHelper.__init__(self)
 
     def _all_entity_data(self) -> None:
         """Helper-function for get_all_gateway_entities().
 
-        Collect data for each entity and add to self._smile_props and self.gw_entities.
+        Collect data for each entity and add to self.gw_entities.
         """
         self._update_gw_entities()
         if self.smile(ADAM):
             self._update_zones()
             self.gw_entities.update(self._zones)
 
-        self._smile_props["gateway_id"] = self._gateway_id
-        self._smile_props["item_count"] = self._count
-        self._smile_props["reboot"] = True
-        self._smile_props["smile_name"] = self.smile_name
-        if self._is_thermostat:
-            self._smile_props["heater_id"] = self._heater_id
-            self._smile_props["cooling_present"] = self._cooling_present
-
     def _update_zones(self) -> None:
         """Helper-function for _all_entity_data() and async_update().
 
@@ -228,6 +218,7 @@ class SmileData(SmileHelper):
                 for msg in item.values():
                     if message in msg:
                         data["available"] = False
+                        break
 
     def _get_adam_data(self, entity: GwEntityData, data: GwEntityData) -> None:
         """Helper-function for _get_entity_data().
@@ -329,16 +320,14 @@ class SmileData(SmileHelper):
 
         Also, replace NONE by OFF when none of the schedules are active.
         """
-        loc_schedule_states: dict[str, str] = {}
-        for schedule in schedules:
-            loc_schedule_states[schedule] = "off"
-            if schedule == selected and data["climate_mode"] == "auto":
-                loc_schedule_states[schedule] = "on"
-        self._schedule_old_states[location] = loc_schedule_states
-
         all_off = True
-        for state in self._schedule_old_states[location].values():
-            if state == "on":
+        self._schedule_old_states[location] = {}
+        for schedule in schedules:
+            active: bool = schedule == selected and data["climate_mode"] == "auto"
+            self._schedule_old_states[location][schedule] = "off"
+            if active:
+                self._schedule_old_states[location][schedule] = "on"
                 all_off = False
+
         if all_off:
             data["select_schedule"] = OFF
