@@ -18,11 +18,11 @@ from plugwise.constants import (
     LOCATIONS,
     MAX_SETPOINT,
     MIN_SETPOINT,
+    NONE,
     NOTIFICATIONS,
     OFF,
     RULES,
     GwEntityData,
-    SmileProps,
     ThermoLoc,
 )
 from plugwise.data import SmileData
@@ -51,7 +51,6 @@ class SmileAPI(SmileData):
         _opentherm_device: bool,
         _request: Callable[..., Awaitable[Any]],
         _schedule_old_states: dict[str, dict[str, str]],
-        _smile_props: SmileProps,
         smile_hostname: str | None,
         smile_hw_version: str | None,
         smile_mac_address: str | None,
@@ -62,6 +61,7 @@ class SmileAPI(SmileData):
         smile_version: Version,
     ) -> None:
         """Set the constructor for this class."""
+        super().__init__()
         self._cooling_present = _cooling_present
         self._elga = _elga
         self._is_thermostat = _is_thermostat
@@ -71,7 +71,6 @@ class SmileAPI(SmileData):
         self._opentherm_device = _opentherm_device
         self._request = _request
         self._schedule_old_states = _schedule_old_states
-        self._smile_props = _smile_props
         self.smile_hostname = smile_hostname
         self.smile_hw_version = smile_hw_version
         self.smile_mac_address = smile_mac_address
@@ -81,7 +80,11 @@ class SmileAPI(SmileData):
         self.smile_type = smile_type
         self.smile_version = smile_version
         self.therms_with_offset_func: list[str] = []
-        SmileData.__init__(self)
+
+    @property
+    def cooling_present(self) -> bool:
+        """Return the cooling capability."""
+        return self._cooling_present
 
     async def full_xml_update(self) -> None:
         """Perform a first fetch of the Plugwise server XML data."""
@@ -121,8 +124,8 @@ class SmileAPI(SmileData):
             self.get_all_gateway_entities()
             # Set self._cooling_enabled - required for set_temperature(),
             # also, check for a failed data-retrieval
-            if "heater_id" in self._smile_props:
-                heat_cooler = self.gw_entities[self._smile_props["heater_id"]]
+            if self.heater_id != NONE:
+                heat_cooler = self.gw_entities[self.heater_id]
                 if (
                     "binary_sensors" in heat_cooler
                     and "cooling_enabled" in heat_cooler["binary_sensors"]
@@ -131,7 +134,7 @@ class SmileAPI(SmileData):
                         "cooling_enabled"
                     ]
             else:  # cover failed data-retrieval for P1
-                _ = self.gw_entities[self._smile_props["gateway_id"]]["location"]
+                _ = self.gw_entities[self.gateway_id]["location"]
         except KeyError as err:
             raise DataMissingError("No Plugwise actual data received") from err
 
@@ -174,8 +177,12 @@ class SmileAPI(SmileData):
         if thermostat_id is None:
             raise PlugwiseError(f"Plugwise: cannot change setpoint, {key} not found.")
 
+        data = (
+            "<thermostat_functionality>"
+            f"<setpoint>{temp}</setpoint>"
+            "</thermostat_functionality>"
+        )
         uri = f"{APPLIANCES};id={self._heater_id}/thermostat;id={thermostat_id}"
-        data = f"<thermostat_functionality><setpoint>{temp}</setpoint></thermostat_functionality>"
         await self.call_request(uri, method="put", data=data)
 
     async def set_offset(self, dev_id: str, offset: float) -> None:
@@ -186,9 +193,8 @@ class SmileAPI(SmileData):
             )
 
         value = str(offset)
-        uri = f"{APPLIANCES};id={dev_id}/offset;type=temperature_offset"
         data = f"<offset_functionality><offset>{value}</offset></offset_functionality>"
-
+        uri = f"{APPLIANCES};id={dev_id}/offset;type=temperature_offset"
         await self.call_request(uri, method="put", data=data)
 
     async def set_preset(self, loc_id: str, preset: str) -> None:
@@ -201,14 +207,16 @@ class SmileAPI(SmileData):
         current_location = self._domain_objects.find(f'location[@id="{loc_id}"]')
         location_name = current_location.find("name").text
         location_type = current_location.find("type").text
-
-        uri = f"{LOCATIONS};id={loc_id}"
         data = (
-            "<locations><location"
-            f' id="{loc_id}"><name>{location_name}</name><type>{location_type}'
-            f"</type><preset>{preset}</preset></location></locations>"
+            "<locations>"
+            f'<location id="{loc_id}">'
+            f"<name>{location_name}</name>"
+            f"<type>{location_type}</type>"
+            f"<preset>{preset}</preset>"
+            "</location>"
+            "</locations>"
         )
-
+        uri = f"{LOCATIONS};id={loc_id}"
         await self.call_request(uri, method="put", data=data)
 
     async def set_select(
@@ -231,9 +239,12 @@ class SmileAPI(SmileData):
         if mode not in self._dhw_allowed_modes:
             raise PlugwiseError("Plugwise: invalid dhw mode.")
 
+        data = (
+            "<domestic_hot_water_mode_control_functionality>"
+            f"<mode>{mode}</mode>"
+            "</domestic_hot_water_mode_control_functionality>"
+        )
         uri = f"{APPLIANCES};type=heater_central/domestic_hot_water_mode_control"
-        data = f"<domestic_hot_water_mode_control_functionality><mode>{mode}</mode></domestic_hot_water_mode_control_functionality>"
-
         await self.call_request(uri, method="put", data=data)
 
     async def set_gateway_mode(self, mode: str) -> None:
@@ -259,9 +270,13 @@ class SmileAPI(SmileData):
             vacation_time = time_2 + "T23:00:00.000Z"
             valid = f"<valid_from>{vacation_time}</valid_from><valid_to>{end_time}</valid_to>"
 
-        uri = f"{APPLIANCES};id={self._smile_props['gateway_id']}/gateway_mode_control"
-        data = f"<gateway_mode_control_functionality><mode>{mode}</mode>{valid}</gateway_mode_control_functionality>"
-
+        data = (
+            "<gateway_mode_control_functionality>"
+            f"<mode>{mode}</mode>"
+            f"{valid}"
+            "</gateway_mode_control_functionality>"
+        )
+        uri = f"{APPLIANCES};id={self.gateway_id}/gateway_mode_control"
         await self.call_request(uri, method="put", data=data)
 
     async def set_regulation_mode(self, mode: str) -> None:
@@ -269,12 +284,17 @@ class SmileAPI(SmileData):
         if mode not in self._reg_allowed_modes:
             raise PlugwiseError("Plugwise: invalid regulation mode.")
 
-        uri = f"{APPLIANCES};type=gateway/regulation_mode_control"
         duration = ""
         if "bleeding" in mode:
             duration = "<duration>300</duration>"
-        data = f"<regulation_mode_control_functionality>{duration}<mode>{mode}</mode></regulation_mode_control_functionality>"
 
+        data = (
+            "<regulation_mode_control_functionality>"
+            f"{duration}"
+            f"<mode>{mode}</mode>"
+            "</regulation_mode_control_functionality>"
+        )
+        uri = f"{APPLIANCES};type=gateway/regulation_mode_control"
         await self.call_request(uri, method="put", data=data)
 
     async def set_schedule_state(
@@ -323,18 +343,22 @@ class SmileAPI(SmileData):
             template = f'<template id="{template_id}" />'
 
         contexts = self.determine_contexts(loc_id, name, new_state, schedule_rule_id)
-        uri = f"{RULES};id={schedule_rule_id}"
         data = (
-            f'<rules><rule id="{schedule_rule_id}"><name><![CDATA[{name}]]></name>'
-            f"{template}{contexts}</rule></rules>"
+            "<rules>"
+            f"<rule id='{schedule_rule_id}'>"
+            f"<name><![CDATA[{name}]]></name>"
+            f"{template}"
+            f"{contexts}"
+            "</rule>"
+            "</rules>"
         )
-
+        uri = f"{RULES};id={schedule_rule_id}"
         await self.call_request(uri, method="put", data=data)
         self._schedule_old_states[loc_id][name] = new_state
 
     def determine_contexts(
         self, loc_id: str, name: str, state: str, sched_id: str
-    ) -> etree:
+    ) -> str:
         """Helper-function for set_schedule_state()."""
         locator = f'.//*[@id="{sched_id}"]/contexts'
         contexts = self._domain_objects.find(locator)
@@ -349,7 +373,7 @@ class SmileAPI(SmileData):
         if state == "on":
             contexts.append(subject)
 
-        return etree.tostring(contexts, encoding="unicode").rstrip()
+        return str(etree.tostring(contexts, encoding="unicode").rstrip())
 
     async def set_switch_state(
         self, appl_id: str, members: list[str] | None, model: str, state: str
@@ -378,18 +402,22 @@ class SmileAPI(SmileData):
             return await self._set_groupswitch_member_state(members, state, switch)
 
         locator = f'appliance[@id="{appl_id}"]/{switch.actuator}/{switch.func_type}'
-        found: list[etree] = self._domain_objects.findall(locator)
+        found = self._domain_objects.findall(locator)
         for item in found:
+            # multiple types of e.g. toggle_functionality present
             if (sw_type := item.find("type")) is not None:
                 if sw_type.text == switch.act_type:
                     switch_id = item.attrib["id"]
-            else:
+                    break
+            else:  # actuators with a single item like relay_functionality
                 switch_id = item.attrib["id"]
-                break
 
+        data = (
+            f"<{switch.func_type}>"
+            f"<{switch.func}>{state}</{switch.func}>"
+            f"</{switch.func_type}>"
+        )
         uri = f"{APPLIANCES};id={appl_id}/{switch.device};id={switch_id}"
-        data = f"<{switch.func_type}><{switch.func}>{state}</{switch.func}></{switch.func_type}>"
-
         if model == "relay":
             locator = (
                 f'appliance[@id="{appl_id}"]/{switch.actuator}/{switch.func_type}/lock'
@@ -411,8 +439,11 @@ class SmileAPI(SmileData):
             locator = f'appliance[@id="{member}"]/{switch.actuator}/{switch.func_type}'
             switch_id = self._domain_objects.find(locator).attrib["id"]
             uri = f"{APPLIANCES};id={member}/{switch.device};id={switch_id}"
-            data = f"<{switch.func_type}><{switch.func}>{state}</{switch.func}></{switch.func_type}>"
-
+            data = (
+                f"<{switch.func_type}>"
+                f"<{switch.func}>{state}</{switch.func}>"
+                f"</{switch.func_type}>"
+            )
             await self.call_request(uri, method="put", data=data)
 
     async def set_temperature(self, loc_id: str, items: dict[str, float]) -> None:
@@ -448,12 +479,12 @@ class SmileAPI(SmileData):
             )  # pragma: no cover"
 
         temperature = str(setpoint)
-        uri = self._thermostat_uri(loc_id)
         data = (
-            "<thermostat_functionality><setpoint>"
-            f"{temperature}</setpoint></thermostat_functionality>"
+            "<thermostat_functionality>"
+            f"<setpoint>{temperature}</setpoint>"
+            "</thermostat_functionality>"
         )
-
+        uri = self._thermostat_uri(loc_id)
         await self.call_request(uri, method="put", data=data)
 
     async def call_request(self, uri: str, **kwargs: Any) -> None:
